@@ -33,6 +33,15 @@
 
 #include "um-utils.h"
 
+void
+set_entry_validation_checkmark (GtkEntry *entry)
+{
+        g_object_set (entry, "caps-lock-warning", FALSE, NULL);
+        gtk_entry_set_icon_from_icon_name (entry,
+                                           GTK_ENTRY_ICON_SECONDARY,
+                                           "object-select-symbolic");
+}
+
 void
 set_entry_validation_error (GtkEntry    *entry,
                             const gchar *text)
@@ -233,24 +242,21 @@ is_valid_username (const gchar *username, gchar **tip)
 
         if (!empty && (in_use || too_long || !valid)) {
                 if (in_use) {
-                        *tip = g_strdup_printf (_("A user with the username '%s' already exists"),
+                        *tip = g_strdup_printf (_("A user with the username '%s' already exists."),
                                                username);
                 }
                 else if (too_long) {
-                        *tip = g_strdup_printf (_("The username is too long"));
+                        *tip = g_strdup_printf (_("The username is too long."));
                 }
                 else if (username[0] == '-') {
-                        *tip = g_strdup (_("The username cannot start with a '-'"));
+                        *tip = g_strdup (_("The username cannot start with a '-'."));
                 }
                 else {
-                        *tip = g_strdup (_("The username must only consist of:\n"
-                                          " \xe2\x9e\xa3 letters from the English alphabet\n"
-                                          " \xe2\x9e\xa3 digits\n"
-                                          " \xe2\x9e\xa3 any of the characters '.', '-' and '_'"));
+                        *tip = g_strdup (_("The username should only consist of lower and upper case letters from a-z, digits and any of characters '.', '-' and '_'."));
                 }
         }
         else {
-                *tip = NULL;
+                *tip = g_strdup (_("This will be used to name your home folder and can't be changed."));
         }
 
         return valid;
